@@ -4,11 +4,11 @@ from decimal import Decimal
 
 from django_libs.tests.factories import UserFactory
 
-from paypal_express_checkout.models import Item, PaymentTransaction
+from .. import models
 
 
 class ItemFactory(factory.Factory):
-    FACTORY_FOR = Item
+    FACTORY_FOR = models.Item
 
     name = factory.Sequence(lambda x: 'item{0}'.format(x))
     description = factory.Sequence(lambda x: 'item descriptio{0}'.format(x))
@@ -16,8 +16,18 @@ class ItemFactory(factory.Factory):
 
 
 class PaymentTransactionFactory(factory.Factory):
-    FACTORY_FOR = PaymentTransaction
+    FACTORY_FOR = models.PaymentTransaction
 
     user = factory.SubFactory(UserFactory)
     transaction_id = factory.Sequence(lambda x: '123abc{0}'.format(x))
     value = Decimal('10.00')
+
+
+class PurchasedItemFactory(factory.Factory):
+    FACTORY_FOR = models.PurchasedItem
+
+    user = factory.SubFactory(UserFactory)
+    transaction = factory.LazyAttribute(
+        lambda x: PaymentTransactionFactory(user=x.user))
+    item = factory.SubFactory(ItemFactory)
+    quantity = 1
